@@ -12,7 +12,7 @@ import yaml
 from rich.console import Console
 
 from np_validator import version
-from np_validator.core import run_validation
+from np_validator.core import autogenerate_validation_steps, run_validation
 from np_validator.dataclasses import dump_ValidationResult, load_ValidationStep
 
 run_id = uuid4().hex
@@ -57,17 +57,23 @@ def main(
 @app.command()
 def validate(
     file_list_path: str,
-    validation_steps_path: str,
     results_path: str,
+    validation_steps_path: str = typer.Option(
+        None,
+    ),
 ) -> None:
     with open(file_list_path) as f:
         file_list = json.load(f)
 
-    with open(validation_steps_path) as f:
-        validation_steps = [
-            load_ValidationStep(step_dict)
-            for step_dict in yaml.load(f.read(), Loader=yaml.Loader)
-        ]
+    if validation_steps_path:
+        with open(validation_steps_path) as f:
+            validation_steps = [
+                load_ValidationStep(step_dict)
+                for step_dict in yaml.load(f.read(), Loader=yaml.Loader)
+            ]
+    else:
+        validation_steps = autogenerate_validation_steps(file_list)
+
     try:
         results = run_validation(
             file_list,
@@ -79,7 +85,12 @@ def validate(
         return
 
     with open(results_path, "w") as f:
-        json.dump([dump_ValidationResult(result) for result in results], f)
+        json.dump(
+            [dump_ValidationResult(result) for result in results],
+            f,
+            sort_keys=True,
+            indent=4,
+        )
 
 
 if __name__ == "__main__":
