@@ -4,11 +4,14 @@ import logging
 
 from .dataclasses import (
     BuiltinCallable,
+    ValidationError,
     ValidationResult,
     ValidationStep,
+    ValidatorResult,
     load_ValidationStep,
+    path_to_ValidationStep,
 )
-from .exceptions import ParsingError, ValidationError
+from .exceptions import ParsingError
 from .path_matching import path_matches_pattern
 
 logger = logging.getLogger(__name__)
@@ -42,7 +45,10 @@ def run_ValidationStep(filepath: str, step: ValidationStep) -> ValidationResult:
             return ValidationResult(
                 filepath=filepath,
                 errors=[
-                    str(e),
+                    ValidationError(
+                        str(e),
+                        # processor=step.processor,
+                    )
                 ],
             )
     else:
@@ -52,24 +58,44 @@ def run_ValidationStep(filepath: str, step: ValidationStep) -> ValidationResult:
     errors = []
     for validator in step.validators:
         try:
+            value, passed = run_BuiltinCallable(
+                processed,
+                validator.builtin,
+            )
             results.append(
-                run_BuiltinCallable(
-                    processed,
-                    validator.builtin,
+                ValidatorResult(
+                    value=value,
+                    passed=passed,
+                    validator=validator,
                 )
             )
         except Exception as e:
-            errors.append(str(e))
+            errors.append(
+                ValidationError(
+                    str(e),
+                    # message=str(e),
+                    validator=validator,
+                )
+            )
 
-    return ValidationResult(
-        filepath=filepath,
-        results=results,
-        errors=errors,
-    )
+    if step.processor:
+        return ValidationResult(
+            filepath=filepath,
+            processor=step.processor,
+            results=results,
+            errors=errors,
+        )
+    else:
+        return ValidationResult(
+            filepath=filepath,
+            results=results,
+            errors=errors,
+        )
 
 
 def run_validation(
-    file_list: List[str], validation_steps: List[ValidationStep]
+    file_list: List[str],
+    validation_steps: List[ValidationStep],
 ) -> List[ValidationResult]:
     """Validates a list of files.
 
@@ -92,3 +118,9 @@ def run_validation(
                 )
 
     return results
+
+
+def autogenerate_validation_steps(
+    file_list: List[str],
+) -> List[ValidationStep]:
+    return list(map(path_to_ValidationStep, file_list))
