@@ -1,6 +1,7 @@
 from types import ModuleType
 from typing import Any, Callable, Dict, List, Optional, Tuple
 
+import os
 from dataclasses import dataclass, field
 
 from .. import processors, validators
@@ -95,12 +96,29 @@ class ValidationStep:
     validators: List[Validator] = field(default_factory=lambda: [])
 
 
+@dataclass
+class ValidatorResult:
+
+    value: Any
+    passed: bool
+    validator: Validator
+
+
+@dataclass
+class ValidationError:
+
+    message: str
+    validator: Optional[Validator] = None
+    processor: Optional[Processor] = None
+
+
 @dataclass
 class ValidationResult:
 
     filepath: str
-    results: List[Any] = field(default_factory=lambda: [])
-    errors: List[str] = field(default_factory=lambda: [])
+    processor: Optional[Processor] = None
+    results: List[ValidatorResult] = field(default_factory=lambda: [])
+    errors: List[ValidationError] = field(default_factory=lambda: [])
 
 
 validation_step_schema = ValidationStepSchema()
@@ -149,3 +167,22 @@ validation_result_schema = ValidationResultSchema()
 
 def dump_ValidationResult(result: ValidationResult) -> dict:
     return validation_result_schema.dump(result)
+
+
+def _extract_path_suffix(path: str) -> str:
+    fname = os.path.basename(path)
+    return fname.split(".", 1)[1]
+
+
+def path_to_ValidationStep(path: str) -> ValidationStep:
+    return ValidationStep(
+        path_suffix=_extract_path_suffix(path),
+        validators=[
+            Validator(
+                name="meets_filesize_threshold",
+                args={
+                    "threshold": 1,
+                },
+            )
+        ],
+    )
