@@ -29,7 +29,7 @@ def unpickle(filepath: str, encoding: str = "latin1") -> Any:
         return pickle.load(f, encoding=encoding)  # nosec
 
 
-def load_data_set(filepath: str) -> Dataset:
+def load_sync_dataset(filepath: str) -> Dataset:
     """Loads a sync Dataset instance from a filepath.
 
     Args:
